;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  database.lsp
;;  This file contains functions to create a database of words stored
;;  with their phonological forms, and search the database based on
;;  a linear combination of the similarity between the cue and those forms.

(setq *dictionary
      '(
        ("Sheri" ((2 (SH) (E) (R)) (1 (R) (EE) (X))))
        ("Shelby" ((2 (SH) (E) (L)) (1 (B) (EE) (X))))
        ("Shelly" ((2 (SH) (E) (L)) (1 (L) (EE) (X)))) 
        ("Shirley" ((2 (SH) (@) (R)) (1 (L) (EE) (X))))
        ("Marissa" ((1 (M) (@) (R)) (2 (R) (I) (X)) (1 (S) (@) (X))))
        ("Marita" ((1 (M) (@) (R)) (2 (R) (I) (X)) (1 (T) (@) (X))))
        ("Melinda" ((1 (M) (@) (L)) (2 (L) (I) (N)) (1 (D) (@) (X))))
        ("Marina" ((1 (M) (@) (R)) (2 (R) (EE) (X)) (1 (N) (@) (X))))
        ("Rodney" ((2 (R) (AH) (D)) (1 (N) (EE) (X))))
        ("Rocky" ((2 (R) (AH) (X)) (1 (K) (EE) (X))))
        ("Robbie" ((2 (R) (AH) (X)) (1 (B) (EE) (X))))
        ("Ronnie" ((2 (R) (AH) (X)) (1 (N) (EE) (X))))
        ("Gregory" ((2 (G R) (E) (X)) (1 (G) (@) (R)) (1 (R) (EE) (X))))
        ("Gabriel" ((2 (G) (A_) (X)) (1 (B R) (EE) (X)) (1 (X) (@) (L))))
        ("Garrison" ((2 (G) (A_) (R)) (1 (R) (@) (X)) (1 (S) (UU) (N))))
        ("Galahad" ((2 (G) (AE) (L)) (1 (L) (@) (X)) (1 (H) (AE) (D))))
        ("pilot" ((2 (P) (AH EE) (L)) (1 (L) (@) (T)))) 
        ("parrot" ((2 (P) (AH EE) (R)) (1 (R) (@) (T))))
        ("private" ((2 (P R) (AH EE) (X)) (1 (V) (@) (T))))
        ("prilate" ((2 (P R) (EE) (L)) (1 (L) (@) (T))))
        ("analyst" ((2 (X) (AE) (X)) (1 (N) (@) (L)) (1 (L) (@) (S T))))
        ("activist" ((2 (X) (AE) (K)) (1 (T) (@) (X)) (1 (V) (@) (S T))))
        ("advocate" ((2 (X) (AE) (D)) (1 (V) (@) (X)) (1 (K) (@) (T))))
        ("acrobat" ((2 (X) (AE) (X)) (1 (K R) (@) (X)) (1 (B) (AE) (T))))
        ("trainer" ((2 (T R) (A_) (X)) (1 (N) (@) (R)))) 
        ("tailor" ((2 (T) (A_) (L)) (1 (L) (@) (R))))
        ("trader" ((2 (T R) (A_) (X)) (1 (D) (@) (R)))) 
        ("taster" ((2 (T) (A_) (X)) (1 (S T) (@) (R))))
        ("clinician" ((1 (K L) (I) (X)) (2 (N) (I) (X)) (1 (SH) (@) (N))))
        ("commander" ((1 (K) (@) (X)) (2 (M) (AE) (N)) (1 (D) (@) (R))))
        ("controller" ((1 (K) (@) (N)) (2 (T R) (O_) (L)) (1 (L) (@) (R))))
        ("composer" ((1 (K) (@) (M)) (2 (P) (O_) (X)) (1 (S) (@) (R))))
        ("Stephanie" ((2 (S T) (E) (X)) (1 (F) (@) (X)) (1 (N) (EE) (X))))
        ("Norma" ((2 (N) (O_) (R)) (1 (M) (@) (X))))
        ("Isabel" ((2 (X) (I) (X)) (1 (Z) (@) (X)) (1 (B) (E) (L))))
        ("Jessica" ((2 (J) (E) (X)) (1 (S) (@) (X)) (1 (K) (@) (X))))
        ("Candace" ((2 (K) (AE) (N)) (1 (D) (@) (S))))
        ("Kimberly" ((2 (K) (I) (M)) (1 (B) (@) (R)) (1 (L) (EE) (X))))
        ("Lisa" ((2 (L) (EE) (X)) (1 (S) (@) (X))))
        ("Desiree" ((1 (D) (E) (X)) (1 (S) (@) (X)) (2 (R) (A_) (X))))
        ("Michael" ((2 (M) (I) (X)) (1 (CH) (@) (L)))) 
        ("Noel" ((2 (N) (O_) (L))))
        ("Scott" ((2 (S K) (AH) (T)))) 
        ("Paul" ((2 (P) (AH) (L))))
        ("Brandon" ((2 (B R) (AE) (N)) (1 (D) (@) (N)))) 
        ("Trevor" ((2 (T R) (E) (X)) (1 (V) (@) (R))))
        ("Nicholas" ((2 (N) (I) (X)) (1 (K) (@) (X)) (1 (L) (@) (S))))
        ("Ramsey" ((2 (R) (AE) (M)) (1 (S) (EE) (X))))
        ("electrician" ((1 (X) (EE) (X)) (1 (L) (E) (K)) (2 (T R) (I) (X)) (1 (SH) (@) (N))))
        ("librarian" ((1 (L) (AH EE) (X)) (2 (B R) (A_) (X)) (1 (R) (EE) (X)) (1 (X) (@) (N))))
        ("zoologist" ((1 (Z) (U_) (X)) (2 (X) (AH) (X)) (1 (L) (@) (X)) (1 (G) (I) (S T))))
        ("hawker" ((2 (H) (AH) (W)) (1 (K) (@) (R)))) 
        ("butcher" ((1 (B) (OO) (X)) (2 (CH) (@) (R))))
        ("ensign" ((1 (X) (E) (N)) (2 (S) (@) (N))))
        ("magician" ((1 (M) (@) (X)) (2 (J) (I) (X)) (1 (SH) (@) (N))))
        ("salesperson" ((2 (S) (A_) (L S)) (1 (P) (@) (R)) (1 (S) (@) (N))))
        ("merchant" ((2 (M) (@) (R)) (1 (CH) (@) (N T))))
        ("cook" ((2 (K) (OO) (K))))
        ("auctioneer" ((1 (X) (AW) (K)) (1 (SH) (@) (X)) (2 (N) (EE) (R))))
        ("flautist" ((2 (F L) (AH OO) (X)) (1 (T) (@) (S T))))
        ("undertaker" ((2 (X) (UU) (N)) (1 (D) (@) (R)) (2 (T) (A_) (X)) (1 (K) (@) (R))))
        ("diplomat" ((2 (D) (I) (P)) (1 (L) (O_) (X)) (1 (M) (AE) (T))))
        ("model" ((2 (M) (AH) (X)) (1 (D) (@) (L))))
        ("journalist" ((2 (J) (UU) (R)) (1 (N) (@) (X)) (1 (L) (@) (S T))))))

  
(setf *weights '(.35 .2 .35 .1))
(setf *cutoff .15)
(setf *return-num 10)

(defun find-word-sim (word-1 word-2)
  (let ((phon-1 (second (assoc word-1 *dictionary :test 'equal)))
        (phon-2 (second (assoc word-2 *dictionary :test 'equal))))
    (if (not (and phon-1 phon-2))
        (progn (print "word not found")
          -1)
      (mapcar #'roundoff 
          (first (evaluate-similarity-list (vectorify-word (process-word phon-1))
                                (vectorify-word (process-word phon-2))))))))

(defun find-ph-sim (phon-1 phon-2)
  (first (evaluate-similarity-list (vectorify-word (process-word phon-1))
                                   (vectorify-word (process-word phon-2)))))


;This combines the four similarity values:  onset, nucleus, rhyme, and stress
(defun combine-similarity (similarities &optional (weights *weights))
  (dot similarities weights ))


(defun is-match (word-1 word-2 &optional (cutoff *cutoff))
  (let ((cutoff .15))
    (if (<
         (combine-similarity (find-word-sim word-1 word-2))
         cutoff)
        word-2)))


(defun is-match-ph (phon-1 word-phon-2 &optional (cutoff *cutoff)) 

  (let* (
         (word-2 (first word-phon-2))
         (phon-2 (second word-phon-2))
         (sim (combine-similarity (find-ph-sim phon-1 phon-2)))
         )
    (if (< sim
           cutoff)
        (list word-2  (roundoff sim)))))



(defun calc-similarities (word)
  (mapcar #'(lambda (x)
              (list (first x)
                    (combine-similarity 
                     (find-word-sim word  (first x)) )))
    *dictionary))




(defun find-matches (word)
  (let* ((initial-target-list
         (sort 
          (find-matches-alt
           (second (assoc word *dictionary :test 'equal))
           '()
           *dictionary)
          #'<
          :key #'cadr))
         (len (length initial-target-list)))
    (nbutlast initial-target-list               ;return only the first *return-num items===
              (- len *return-num))              ;take off len - *return-num off the end
   ))

(defun find-matches-alt (phon list-of-matches dict )
  (if (endp dict)
        list-of-matches
       
    (let ( (match (is-match-ph phon (first dict)))
          )

      (if match
          (find-matches-alt phon 
                            (append list-of-matches (list match))
                            (rest dict))
        (find-matches-alt phon
                          list-of-matches
                          (rest dict))
        ))))

              

;(find-matches "Shelly")
;(find-matches "Marita")
;(find-matches "Rodney")
;(find-matches "Noel")