;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  database.lsp
;;  This file contains functions to create a decay-based memory model,
;;  based on the desctruction of phonological features.
;; 


;;;============================================================================
;;;          DESTROY:  primitive utility to simulate decay
;;;============================================================================
;Does not handle null phonemes well


(defun destroy-phoneme (phoneme hazard-rate &optional (destroyed-phoneme '()))
  (cond ((endp phoneme) destroyed-phoneme)
        ((< (random 1.0) hazard-rate)
         (destroy-phoneme (rest phoneme)
                          hazard-rate
                          (append destroyed-phoneme (list 0 ))))
        (t (destroy-phoneme (rest phoneme)
                            hazard-rate
                            (append destroyed-phoneme (list (first phoneme)))))))

(defun destroy-phoneme-group (phoneme-group hazard-rate &optional(destroyed-group '()))
  (cond ((endp phoneme-group) destroyed-group)
        (t (destroy-phoneme-group (rest phoneme-group)
                                  hazard-rate
                                  (append destroyed-group
                                          (list (destroy-phoneme (first phoneme-group) hazard-rate)))))))

(defun destroy-syllable (syllable hazard-rate)
  (let* ((weight           (first syllable))
         (k               (if  (= weight 1)
                            1
                            *k-weight))
         (k-hazard        (- 1 (expt (- 1 hazard-rate) k))))
    (list weight
          (destroy-phoneme-group (second syllable) k-hazard)
          (destroy-phoneme-group (third syllable)  k-hazard)
          (destroy-phoneme-group (fourth syllable) k-hazard))))

(defun destroy-word (word hazard-rate)
  (destroy-word-aux (vectorify-word word) hazard-rate))

(defun destroy-word-aux (word hazard-rate &optional (destroyed-word '()))
  (cond ((endp word) destroyed-word)
        (t (destroy-word-aux (rest word)
                             hazard-rate
                             (append destroyed-word
                                     (list (destroy-syllable (first word) hazard-rate)))))))



;;;this takes a list of phonemes (non-vectors) and returns a degraded vector
(defun destroy-list (vector-list hazard-rate &optional (destroyed-list nil))
  (cond ((endp vector-list) destroyed-list)
        (t (destroy-list (rest vector-list)
                         hazard-rate
                         (append destroyed-list
                                 (list (destroy-word (first vector-list) hazard-rate)))))))


;


(defun trial (word list hazard-rate)
  (make-probability-list
   (make-value-list
    (destroy-word word
                  hazard-rate)
    list)))

