;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  nonwords.lsp
;;  This file computes the similarity dimensions of about 100 wordlike nonwords

;;input-dictionary must have form ## word (phonemes as lisp structure)
;;There should be a cr in the last line to avoid and eof error

(defvar *output-files* nil)
(defvar *nonword-dict* nil)
(defvar *input-stream* nil)


(defun input-dictionary ()
  (SETF *input-stream*  (open "..//words//nonwords.dat" :direction :input))       
  (setf *nonword-dict* (make-array 104 :fill-pointer 0))
    (dotimes (i 104)                                           ;This may have to be changed depending on the content of phones.dat
      (progn
        (print i)
        
         (PRINT (read *input-stream*))                             ;reads the word
         (read *input-stream*)                             ;reads the word
        (vector-push (read *input-stream*) *nonword-dict*)          ;This reads the phonemes
        ))
    (close *input-stream*)
    )
  
 




(defun open-matrix-files ()
  (setf *output-files*
    (list
     (list 'onset   (open "..//dat//nw-onset.mat" :direction :output :if-exists nil ))
     (list 'nucleus (open "..//dat//nw-nucleus.mat" :direction :output :if-exists nil))
     (list 'coda    (open "..//dat//nw-coda.mat" :direction :output :if-exists nil))
     (list 'stress  (open "..//dat//nw-stress.mat" :direction :output :if-exists nil))
     (list 'initial (open "..//dat//nw-initial.mat" :direction :output :if-exists nil))
     )
    )
  )

(defun append-matrix-files ()
  (setf *output-files*
        (list
         (list 'onset   (open "..//nw-onset.mat" :direction :output :if-exists append ))
         (list 'nucleus (open "..//nw-nucleus.mat" :direction :output :if-exists append))
         (list 'coda    (open "..//nw-coda.mat" :direction :output :if-exists append))
         (list 'stress  (open "..//nw-stress.mat" :direction :output :if-exists append))
         (list 'initial (open "..//nw-initial.mat" :direction :output :if-exists append))
         
         )
        )
  )
  
(defun close-matrix-files ()
  
   (mapcar #'close
          (mapcar #'second *output-files*)
   )
  )

;given a file label from *output-files*, this will output the given variable

(defun output-to-file (data filekeyname)
  (prin1 data (second (assoc filekeyname *output-files*)) )
  (write-char #\space (second (assoc filekeyname *output-files*)) ))

(defun print-cr ()
  (let ((file-streams (second (transpose *output-files*))))
    (mapcar #'(lambda (stream)  (write-char #\return stream))
      file-streams)))

(defun print-to-all (object)
  (let ((file-streams (second (transpose *output-files*))))
    (mapcar #'(lambda (stream)  (prin1 object stream))
            file-streams)))

(defun print-out-word-pair (word1 word2)
 ; (PRINT "PRINT-OUT-WORD-PAIR")
  (let* ((base-profile (evaluate-similarity-list (vectorify-word (process-word word1)) 
                                                  (vectorify-word (process-word word2))))
         (stream-names (mapcar #'first *output-files*))
         (l  (length base-profile))
         (syllable-average  (mapcar #'(lambda (x) (roundoff (/ (apply #'+ x) l)))
                                    (transpose base-profile)))
         (initial (initial-distance word1 word2))
         (data (append syllable-average (list initial))))
    (mapcar #'(lambda (data stream) (output-to-file data stream))
      data
      stream-names)))

;This calculates the distance of the initial phonemes of a pair of words.
;
;
(defun initial-distance (word1 word2) 
  (let ((word-1-initial (get-initial word1))
        (word-2-initial (get-initial word2))
        )
    (roundoff (phoneme-distance (vectorify-phoneme word-1-initial)
                      (vectorify-phoneme word-2-initial)))))

(defun get-initial (word)
  (let ((consonant (first (second (first word))))
        (vowel (first (third (first word)))))
    (if (equal consonant 'X)
        vowel
      consonant)))


;use loop  to avoid heavy memory loadage
(defun process-word-for-np (word)
  ;(print-to-all word)
  (dotimes (i 104)
    (if (= 0 (mod i 20)) (format t "."))
    (print-out-word-pair word  (aref *nonword-dict* i))
    )
  (print-cr)
  )


;;
;;This processes the nonwords
;;Make sure to delete output files between runs, or open-matrix-files won't work
(setf *average-ss-distance* .356)
(setf *average-consonant-distance* .37)
(setf *average-lg-distance* .53)

(progn
  (input-dictionary)
  (open-matrix-files)
  (dotimes (j 104)
    (prin1 j)
    (print  (aref *nonword-dict* j))
    (process-word-for-np (aref *nonword-dict* j))
    )
  (close-matrix-files)
  )