;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  util.lsp
;;  This file defines a bunch of general-purpose utility functions that are
;;  used in PSIMETRICA. 



;;;The following utility makes Luce stuff easier
(defun e-to-minus-x (x)
  (exp (* -1
          *temperature
          x)))



;;takes an n by m matrix and returns an m by n matrix
;(defun transpose (matrix &optional (new-matrix nil))
;  (if (endp (first matrix))
;    new-matrix
;    (transpose (map 'list
;                    #'(lambda (l) (rest l))
;                    matrix)
;               (append new-matrix
;                       (list (map 'list
;                                  #'(lambda (l) (first l))
;                                  matrix))))))

;This takes a list generated by trial and changes it to a list of two lists;
; one list of words and one list of probabilities
;;Transposes a list.  
;; Don't ask me how it works
;;
;; rows must be of equal lengths.

(defun transpose(l)  (apply 'mapcar (cons 'list l))) 


;;This function returns the diagonal of a square matrix
(defun diag (m &optional (diag-so-far nil))
  (if (endp m)
    diag-so-far
    (diag  (rest (transpose (rest m)))
          
          (append diag-so-far
                    (list (first (first m)))))))


;;;;randomly pick number elements from list
(defun pick (main-list number &optional new-list)
  (let* ((l (length main-list))
         (r (random l)))
    (cond ((= number 0) new-list)
          ((> number l) nil)
          (t (pick (set-difference main-list
                                   (list (nth r main-list)))
                   (1- number)
                   (append new-list
                           (list (elt main-list r))))))))



(defun sum-list (similarities &optional (sumlist nil))
  (cond ((endp similarities)  (apply '+ sumlist))
        (t (sum-list (rest similarities)
                     (append sumlist
                             (list (apply '+ (first similarities))))))))



(defun s-to-d (number &optional (parameter 15))
  (exp (* -1 parameter number)))


(defun convert-sims-vector (sim-vector)
  (let* ((d-vector (map 'list #'s-to-d sim-vector))
         (d-vectorsum (apply '+ d-vector)))
    (map 'list #'(lambda (x) (roundoff (/ x d-vectorsum))) d-vector)))


(defun roundoff (number &optional (p 5))
  (/ (round (* number (expt 10 p))) (expt 10 p) 1.0))

(defun mean-distance (l1)
  (let* ((l (length l1))
         (n (* l (1- l))))
    (roundoff (/ (sum-list (list-to-list l1 l1))
                 n))))



;;dot product
(defun dot (x y)
  (apply #'+ (mapcar #'* x y)))



;;produces a matrix of cross-similarities by syllable
(defun get-syllable-matrix (list n)
  (mapcar #'(lambda (x) 
              (mapcar #'(lambda (y) 
                          (/ (apply #'+    (mapcar #'(lambda (z) (nth n z))  y)) (length (first list)))
                             )
                          x))
    (cross-evaluate-list-list (p-l list))))


           
           
(defun insert (item  list-of-items position)
  (IF (< position 1) (setf position 1))
  
  (append (butlast list-of-items (- (length list-of-items) position -1))
          (list item)
          (nthcdr  (- position 1) list-of-items)
          ))


;This creates a list of number 1 through k

(defun count-list (min max)
  (let ((x '()))
    (loop for i from min to max
        do (setf x (append x (list i))))
  x))

;start is the first position that you can insert an item into
(defun make-one-longer (l-d)
  (let ((l (first l-d))
        (start (second l-d))
        (x '(0 ((1 1 1 1 1 1 1 1 1 1 1 1 1)) ((1 1 1 1 1 1 1 1 1 1 1 1 1)) ((1 1 1 1 1 1 1 1 1 1 1 1 1)) )))
;  (print (list start l))
  (mapcar #'(lambda (z) (list (insert x l z) (+ z 1)))
    (count-list start (+ (length l) 1))
    )))


;;;============================================================================
;;;  make-n-longer takes a word and a length that you want to make the word (in syllables)
;;;  It returns a list (at least one long) of potentials
;;;============================================================================
(defun make-n-longer (l final-length)
  (if (< (length l) final-length)
      (make-n-longer-alt (list (list l 1)) final-length)
      (list l)))
;this takes a list of (list depth) lists.  Appropriate depth can vary by list, so it can
; not be passed for the entire set.
; make-n-longer should handle this transparently


(defun make-n-longer-alt (l-d final-length)
    (if (= final-length (length (first (first l-d)))) 
      (first (transpose l-d))
    (make-n-longer-alt (mapcan #'copy-list (mapcar #'(lambda (x) (make-one-longer x))
                                         l-d      ;list of current list-depth combos
                                         ))
                  final-length
                   )
      ))


;;This take a similarity measure which in n syllables long and returns 
;; a one-syllable similarity profile
;; No need to use roundoff because sum-list does this eventually
;; put final results in list so that we are compatable with
;; matrix functions that process words of multiple syllables

(defun collapse-across-syllables (word)
  (list (mapcar #'(lambda (x) (/ (apply '+ x) (length x))) (transpose word))))


