;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  adamk.lsp
;;  This file loads contains redefinitions of 1-,2-, and 3-syllable word sets
;;  in the hopes of equalizing phonological similarity between them.  Used by 
;;  Adam Krawitz in to-be-published experiments.
;;

(setf *average-ss-distance* .356)
(setf *average-consonant-distance* .37)
(setf *average-lg-distance* .53)


(setf l1-ak '(
				  ;;((2 (k) (@) (l t)))  ;cult
				  ((2 (d) (a_) (r)))     ;dare
				  ((2 (f) (a_) (t)))     ;fate
				  ;;((2 (g) (e)  (s)))   ;guess
				  ((2 (h) (i)  (n t)))   ;hint
				  ((2 (m) (u_) (d)))     ;mood
				  ((2 (X) (o_) (th)))    ;oath
				  ((2 (p l) (ee) (X)))   ;plea
				  ((2 (r)   (uu)  (sh))) ;rush
				  ((2 (t r) (u_) (th)))  ;truth
				  ((2 (v)   (@)  (r b))) ;verb
				  ((2 (z)  (ee) (l))))   ;zeal
      )



(setf l2-ak '(
				  ((1 (b) (@) (X))        (2 (l) (ee) (f)))     ;belief
				  ((1 (d) (@) (X))        (2 (l) (ah ee) (t)))  ;delight
				  ((2 (g l) (o_) (X))     (1 (r) (ee) (X)))     ;glory
				  ;;  ((2 (h) (ah ee) (X))    (1 (b r) (i) (d)))    ;hybrid
				  ((2 (j) (uu) (j))       (1.5 (m) (@) (n t)))  ;judgment
				  ((2 (k) (ah ee) (n d))  (1 (n) (@) (s)))      ;kindness
				  ((2 (l) (ah) (X) )      (1 (j) (i) (k)))      ;logic
				  ((2 (m) (i) (s))        (1 (ch) (@) (f)))     ;mischief
				  ((2 (n) (ah) (n))       (1 (s) (e) (n s)))    ;nonsense
				  ;;   ((2 (X) (ah oo) (t))    (1.5 (k) (uu) (m)))   ;outcome
				  ((1 (R) (@) (X))        (2 (v) (e) (n j)))    ;revenge
				  ((2 (t) (e) (X))        (1 (n y) (@) (r)))     ;tenure
				  ))

(setf l3-ak '(
				  ((1 (X)  (@) (d))    (2 (v) (ae)   (n))  (1 (t)   (@)    (j)))         ;advantage
				  ((1 (b)  (ee) (X))  (2 (h) (a_)   (X))   (1 (v) (ee @)    (r)))        ;behavior
				  ((2 (s)  (@)  (r))  (1 (k) (@)    (m))   (1 (s t) (ae)   (n s)))       ;circumstance
				  ;; ((1 (d)  (@)  (X))  (2 (f) (ah ee)(X))   (1 (X)   (@)    (n s)))    ;defiance
				  ((2 (f)  (ae) (n))  (1 (t) (@)    (X))   (1 (s)   (ee)   (X)))         ;fantasy
				  ;; ((2 (X)  (i)  (n))  (1 (t) (@)    (X))   (1 (r)   (@)    (m)))      ;interim
				  ((2 (m)  (i)  (X))  (1 (z) (@)    (X))   (1 (r)   (ee)   (X)))         ;misery
				  ((2 (n)  (ae) (X))  (1 (r) (o_)   (X))   (1 (n)   (e)    (s)))         ;narrowness
				  ((1 (X)  (@) (X))   (2 (k) (a_)   (X))   (1 (zh)  (@)    (n)))         ;occasion
				  ((2 (P R) (O_) (X))  (1 (T) (@)    (X))  (1 (K)   (ah)   (L)))         ;protocol
				  ((2 (R)  (I)  (X))  (1 (D) (@)    (X))   (1 (K)  (ee U_)   (L)))       ;ridicule
				  ((1 (X)  (@) (p))   (2 (h) (ee)   (X))   (1 (v)   (@)    (l)))         ;upheaval
				  ))


;; Evaluate their similarity.
(progn (mapcar 'print
              
  (list
   (divide-similarity-profile-by-n (sum-matrix-list (cross-evaluate-list-list (p-l l1-ak))) (* (length l1) (- (length l1) 1)))
   (divide-similarity-profile-by-n (sum-matrix-list (cross-evaluate-list-list (p-l l2-ak))) (* (length l2) (- (length l2) 1)))
   (divide-similarity-profile-by-n (sum-matrix-list (cross-evaluate-list-list (p-l l3-ak))) (* (length l3) (- (length l3) 1)))
   ))
		 nil)
