;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  vw.lsp
;;  Some of the words used in Vitz & Winkler, 1973
;;  Used by src/analyze-vw.lsp

(DEFVAR VW-EXP2 '(
                  ((2 (S K R )(EE )(CH )))     ;screech
                  ((2 (B R )(I )(K S )))        ;bricks 
                  ((2 (K R )(AH OO )(D )))       ;crowd  
                  ((2 (W )(A_ )(V Z )))	       ;waves  
                  ((2 (H )(AH )(R M D )))       ;harmed 
                  ((2 (L )(I )(M P S )))	       ;limps  
                  ((2 (D R )(I )(NG K )))        ;drink  
                  ((2 (S M )(AH )(R T )))        ;smart  
                  ((2 (B L )(A_ )(M D )))       ;blamed 
                  ((2 (P )(AH )(R K S )))       ;parks  
                  ((2 (G R )(AE )(M Z )))       ;grams  
                  ((2 (K R )(AE )(M P )))       ;cramp  
                  ((2 (F L )(UU )(SH T )))     ;flushed
                  ((2 (B L )(AH )(N D )))       ;blond  
                  ((2 (P )(I )(R S T )))       ;pierced
                  ((2 (S T )(AE )(N D )))        ;stand  
                  ((2 (P L )(AH )(T S )))        ;plots  
                  ((2 (S P L )(I )(T )))	       ;split  
                  ((2 (P R )(AE )(NG K )))       ;prank  
                  ((2 (G R )(AE )(N T )))        ;grant  
                  ((2 (P L) (AE ) (S T)))        ;plast  
                  ((2 (P L) (I ) (N T)))	       ;plint  
                  ((2 (P L )(AE )(N Z )))        ;plans  
                  ((2 (P R) (AE) (N T)))	       ;prant  
                  ((2 (S L )(AE )(N T )))        ;slant
                  ))
(DEFVAR VW-EXP2-STANDARD   '((2 (P L )(AE )(N T ))))        ;plant


(DEFVAR VW-EXP1 '(
                  ((2 (W )(A_ )(J )))	       ;wage   
                  ((2 (R )(U_ )(L )))	       ;rule   
                  ((2 (K )(EE )(Z )))	       ;keys   
                  ((2 (X )(E )(N D )))	       ;end    
                  ((2 (T )(A_ )(K )))	       ;take   
                  ((2 (T )(AW )(L )))           ;tall 
                  ((2 (D )(O_ )(S )))	       ;dose 
                  ((2 (T )(AE )(S )))	       ;tass 
                  ((2 (T )(AW )(S )))	       ;toss 
                  ((2 (M )(E )(S )))	       ;mess 
                  ((2 (X )(I )(M P )))	       ;imp  
                  ((2 (F )(EE )(T )))	       ;feet 
                  ((2 (CH )(I )(N )))	       ;chin 
                  ((2 (B )(UU )(T )))	       ;but  
                  ((2 (L )(AH EE )(V )))        ;live 
                  ((2 (S )(AW )(NG )))	       ;song 
                  ((2 (T )(I )(N )))	       ;tin  
                  ((2 (THZ )(I )(S )))	       ;this 
                  ((2 (M )(I )(S )))	       ;miss 
                  ((2 (X )(I )(T S )))	       ;its  
                  ((2 (S )(AE )(T )))	       ;sat  
                  ((2 (S )(E )(T )))	       ;set  
                  ((2 (S )(I )(K )))	       ;sick 
                  ((2 (P )(I )(T )))	       ;pit  
                  ((2 (H )(I )(T )))	       ;hit  
                  ))
(DEFVAR VW-EXP1-STANDARD '((2 (S )(I )(T ))))	       ;sit

(DEFVAR VW-EXP3 '(
                  ((2 (S )(I )(X ))(1 (K )(UU )(L Z )))      ;sickles  
                  ((2 (T )(AW )(X ))(1 (S )(I )(NG )))	   ;tossing  
                  ((2 (L) (AH ) (X)) (1 (K ) (@) (T)))	   ;locket   
                  ((2 (R )(A_ )(X ))(1 (Z )(I )(NG )))	   ;raising  
                  ((2 (R )(AE )(X ))(1 (P )(UU )(D )))	   ;rapid    
                  ((2 (CH ) (I ) (X)) (1 (N) (I) (NG)))	   ;chinning 
                  ((2 (B )(UU )(X ))(1 (K )(UU )(T )))	   ;bucket   
                  ((2 (K R) (A_) (X )) (1 (D ) (@) (L)))	   ;cradel   
                  ((2 (W )(I )(X ))(1.5 (L )(O_ )(Z )))	   ;willows  
                  ((2 (M )(E )(M ))(1 (B )(@ )(R )))	   ;member   
                  ((2 (K )(UU )(X ))(1 (L )(@ )(R Z )))	   ;colors   
                  ((2 (H )(AE )(N ))(1 (D )(UU )(L )))	   ;handle   
                  ((2 (B )(UU )(X ))(1 (T L )(@ )(R )))	   ;butler   
                  ((2 (D )(A_ )(N ))(1 (J )(@ )(R )))	   ;danger   
                  ((2 (W )(I )(X ))(1 (D )(O_ )(Z )))	   ;widows   
                  ((2 (B )(UU )(N ))(1 (D )(UU )(L )))	   ;bundle   
                  ((2 (T )(E )(N ))(1 (D )(@ )(R )))	   ;tender   
                  ((2 (W )(I )(N ))(1 (D )(UU )(L )))	   ;windle   
                  ((2 (W )(E )(L ))(1 (D )(@ )(R )))	   ;welder   
                  ((2 (W )(I )(N ))(1 (T )(@ )(R )))	   ;winter   
                  ((2 (W )(UU )(Z ))(1 (D )(@ )(R )))	   ;wuzder   
                  ((2 (W )(UU )(N ))(1 (D )(@ )(L )))	   ;wundle   
                  ((2 (W )(AH )(N ))(1 (D )(@ )(R )))	   ;wander   
                  ((2 (S )(UU )(N ))(1 (D )(@ )(R )))	   ;sunder   
                  ((2 (W )(UU )(N ))(1 (T )(@ )(R )))	   ;wunter
                  ))
(DEFVAR VW-EXP3-STANDARD '((2 (W )(UU )(N ))(1 (D )(@ )(R ))))   ;wonder   

(DEFVAR VW-EXP4 '(
                  ((2 (G )(E )(T )))			   ;get      
                  ((1 (X )(AE )(Z ))(2 (M )(AE )(X ))(1 (T )(I )(K )))                     ;asthmatic
                  ((1 (D )(I )(X ))(2 (T )(@ )(R Z )))                                ;deters      
                  ((2 (H )(E )(X ))(1 (Z )(UU )(X ))(1.5 (T )(A_ )(T )))		   ;hesitate    
                  ((2 (F )(AE )(X ))(1 (S )(UU )(X ))(1.5 (N )(A_ )(X ))(1 (T )(I )(NG )))  ;fascinating 
                  ((2 (S )(UU )(N )))							   ;sun         
                  ((1 (X )(I )(X ))(2 (F )(E )(K T )))					   ;effect      
                  ((1 (B )(I )(X ))(2 (K )(UU )(M )))					   ;become      
                  ((2 (R )(I )(CH )))							   ;rich        
                  ((2 (L )(E )(X ))(1 (J )(I )(X ))(1.5 (S L )(A_ )(T S )))		   ;legislates  
                  ((1 (M )(UU )(X ))(2 (K )(AE )(X ))(1 (N )(I )(K ))) 		   ;mechanic    
                  ((2 (X )(UU )(N ))(1 (D )(@ )(R ))(1.5 (R )(I )(X ))(1 (T )(UU )(N )))  ;underwritten
                  ((2 (P )(A_ )(N )))							   ;pain        
                  ((2 (L )(AE )(SH )))							   ;lash        
                  ((2 (R )(UU )(SH )))							   ;rush        
                  ((1 (R )(I )(X ))(2 (P )(E )(L )))					   ;repel       
                  ((1.5 (X )(I )(N ))(1 (H )(UU )(X ))(2 (B )(I )(X ))(1 (SH )(UU )(N )))  ;inhibition  
                  ((1 (X )(I )(X ))(2 (M )(O_ )(X ))(1 (SH )(UU )(N Z )))		   ;emotions    
                  ((1.5 (R )(E )(X ))(1 (Z )(UU )(X ))(2 (L )(U_ )(X ))(1 (SH )(UU )(N )))  ;resolution  
                  ((1.5 (L )(AE )(X ))(1 (S )(@ )(X ))(2 (R )(A_ )(X ))(1 (SH )(UU )(N )))  ;laceration  
                  ((1 (R )(EE )(X ))(2 (V )(I )(X ))(1 (ZH )(UU )(N )))			   ;revision    
                  ((1 (R )(I )(X ))(2 (L )(A_ )(T )))					   ;relate      
                  ((1 (L )(O_ )(X ))(2 (K )(A_ )(X ))(1 (SH )(UU )(N )))                     ;location  
                  ((2 (R )(AE )(X ))(1 (SH )(UU )(N )))		                          ;ration	
                  ((1 (B )(EE )(X ))(2 (L )(A_ )(X ))(1 (SH )(UU )(N )))                    ;belation
                  ))
(DEFVAR VW-EXP4-STANDARD '((1 (R )(EE )(X ))(2 (L )(A_ )(X ))(1 (SH )(UU )(N ))))                    ;relation  
                  