;; PSIMETRICA:  Phonological SIMilarity METRIC Analysis
;; (c) 1998-2004 Shane T. Mueller
;; stmuelle@indiana.edu
;; More info at: http://mypages.iu.edu/~stmuelle
;; May not be copied or distributed without permission.
;; Tools and routines for measuring phonological similarity between words.
;;
;;  words.lsp
;;  This file defines and transcribes a bunch of word sets used by
;;  in psychological experiments.
;;  It begins with a definition of the phonemes, along with
;;  examples, for easy transcription.
													 
;symbol  feature-vector                IPA symbol......MRC.......Example
;(defvar *phonemes*    '((ee  (+ - + - - - - - + x x x x))  ;lower-case i...i.........steam
;                        (i   (+ - + - - - - - - x x x x))  ;block i........I.........pits
;                        (a_  (+ - - - - - - - + x x x x))  ;e..............eI........late
;                        (e   (+ - - - - - - - - x x x x))  ;epsilon........e.........mess
;                        (ae  (+ - - - + - - - + x x x x))  ;ae.............&.........fat
;                        (u   (+ - + + - - - - - x x x x))  ;ibar........... .........just
;                        (@   (+ - - + - - - - - x x x x))  ;inverse e...... .........burn, eatEn, Above
;                        (uu  (+ - - + + - - - - x x x x))  ;inverse v......V.........rUbber,abOve
;                        (ah  (+ - - + + - - - + x x x x))  ;a..............A.........hAlf (british, as in car??)
;                        (u_  (+ - + + - - - + + x x x x))  ;u..............u.........crUise
;                        (oo  (+ - + + - - - + - x x x x))  ;block U........U.........cOOk
;                        (o_  (+ - - + - - - + + x x x x))  ;o..............O.........cOAt
;                        (aw  (+ - - + + - - + - x x x x))  ;backwards c....0 (zero)..bAWl
;                        (y   (- - + - - - - - - x x x x))  ;j..............j.........Yell
;                        (w   (- - + + - - - + - x x x x))  ;w..............w.........Wool
;                        (r   (+ + - - - - + x x + + - -))  ;r..............r.........Rat
;                        (l   (+ + - - - + + x x + + - -))  ;l..............l.........Loin
;                        (h   (- - - - + - - x x - + - -))  ;h..............h.........Hot
;                        (p   (- + - - - + - x x - - - -))  ;p..............p.........Pot
;                        (b   (- + - - - + - x x + - - -))  ;b..............b.........But
;                        (t   (- + - - - + + x x - - - -))  ;t..............t.........Top
;                        (d   (- + - - - + + x x + - - -))  ;d..............d.........Dog
;                        (ch  (- + + - - - + x x - - - +))  ;tSigma.........tS........CHurCH
;                        (j   (- + + - - - + x x + - - +))  ;d3.............dZ........Jowls
;                        (k   (- + + + - - - - x - - - -))  ;k..............k.........Cramp
;                        (g   (- + + + - - - - x + - - -))  ;g..............g.........Goon
;                        (f   (- + - - - + - x x - + - +))  ;f..............f.........Feeler
;                        (v   (- + - - - + - x x + + - +))  ;v..............v.........Vain
;                        (th  (- + - - - + + x x - + - -))  ;theta..........T.........THought
;                        (thz (- + - - - + + x x + + - -))  ;delta..........D.........THis
;                        (s   (- + - - - + + x x - + - +))  ;s..............s.........Sign
;                        (z   (- + - - - + + x x + + - +))  ;z..............z.........Zircon
;                        (sh  (- + + - - - + x x - + - +))  ;sigma..........S.........SHeet
;                        (zh  (- + + - - - + x x + + - +))  ;3..............Z.........viSIon
;                        (m   (- + - - - + - x x + - + -))  ;m..............m.........MiMe
;                        (n   (- + - - - + + x x + - + -))  ;n..............n.........Numb
;                        (ng  (- + + + - - - x x + - + -))  ;eta............9.........youNG
;                        (X   (1 1 1 1 1 1 1 1 1 1 1 1 1))  ;default placeholder
;                        (XX  (0 0 0 0 0 0 0 0 0 0 0 0 0))  ;default nil phoneme
;                        ;total:  37 phonemes +2 placeholder
;                        ))



;; l1 and l3 are used in Mueller et al., 2003.  L2 is a comparative 2-syllable set.
(setf l1 '(((2 (k) (@) (l t)))
           ((2 (d) (a_) (r)))
           ((2 (f) (a_) (t)))
           ((2 (g) (e)  (s)))
           ((2 (h) (i)  (n t)))
           ((2 (m) (u_) (d)))
           ((2 (X) (o_) (th)))
           ((2 (p l) (ee) (X)))
           ((2 (r)   (uu)  (sh)))
           ((2 (t r) (u_) (s)))
           ((2 (v)   (@)  (r b)))
           ((2 (z)  (ee) (l)))))

(setf l1b '(((2 (k) (@) (l t)))
           ((2 (d) (a_) (r)))
           ((2 (f) (a_) (t)))
           ((2 (g) (e)  (s)))
           ((2 (h) (i)  (n t)))
           ((2 (m) (u_) (d)))
           ((2 (X) (o_) (th)))
           ((2 (p l) (ee) (X)))
           ((2 (r)   (uu)  (sh)))
           ((2 (t r) (u_) (th)))
           ((2 (v)   (@)  (r b)))
           ((2 (z)  (ee) (l)))))



(setf l2 '(
           ((1 (b) (@) (X))        (2 (l) (ee) (f)))       ;belief
           ((1 (d) (@) (X))        (2 (l) (ah ee) (t)))    ;delight
           ((2 (g l) (o_) (X))     (1 (r) (ee) (X)))    ;glory
           ((2 (h) (ah ee) (X))    (1 (b r) (i) (d)))  ;hybrid
           ((2 (j) (uu) (j))       (1.5 (m) (@) (n t))) ;judgment
           ((2 (k) (ah ee) (n d))  (1 (n) (@) (s)))  ;kindness
           ((2 (l) (ah) (X) )      (1 (j) (i) (k)))  ;logic
           ((2 (m) (i) (s))        (1 (ch) (@) (f))) ;mischief
           ((2 (n) (ah) (n))       (1 (s) (e) (n s)));nonsense
           ((2 (X) (ah oo) (t))    (1.5 (k) (uu) (m)))  ;outcome
           ((1 (R) (@) (X))        (2 (v) (e) (n j)))   ;revenge
           ((2 (t) (e) (X))       (1 (n y) (@) (r))) ;tenure
           ))

(setf l3 '(((1 (X)  (@) (d))    (2 (v) (ae)   (n))  (1 (t)   (@)    (j)))
           ((1 (b)  (ee) (X))  (2 (h) (a_)   (X))   (1 (v) (ee @)    (r)))
           ((2 (s)  (@)  (r))  (1 (k) (@)    (m))   (1 (s t) (ae)   (n s)))
           ((1 (d)  (@)  (X))  (2 (f) (ah ee)(X))   (1 (X)   (@)    (n s)))
           ((2 (f)  (ae) (n))  (1 (t) (@)    (X))   (1 (s)   (ee)   (X)))
           ((2 (X)  (i)  (n))  (1 (t) (@)    (X))   (1 (r)   (@)    (m)))
           ((2 (m)  (i)  (X))  (1 (z) (@)    (X))   (1 (r)   (ee)   (X)))
           ((2 (n)  (ae) (X))  (1 (r) (o_)   (X))   (1 (n)   (e)    (s)))
           ((1 (X)  (@) (X))   (2 (k) (a_)   (X))   (1 (zh)  (@)    (n)))
           ((2 (P R) (O_) (X))  (1 (T) (@)    (X))  (1 (K)   (ah)   (L)))
           ((2 (R)  (I)  (X))  (1 (D) (@)    (X))   (1 (K)  (ee U_)   (L)))
           ((1 (X)  (@) (p))   (2 (h) (ee)   (X))   (1 (v)   (@)    (l)))))




;;Words used by Caplan, Rochon, & Waters, 1992
(setf cw1 '(((2 (k r) (a_)    (X)) (1 (y) (@)    (n)))
            ((2 (v)   (ae)    (X)) (1 (k) (ee u_)   (m)))
            ((2 (s)   (@)     (r)) (1 (l) (o_ ee) (n)))
            ((2 (s p) (ah ee) (X)) (1 (d) (@)    (r)))
            ((1 (b)   (@)     (X)) (2 (l) (u_)   (n)))
            ((2 (b)   (a_ ee) (X)) (1 (b) (ee)   (X)))
            ((2 (t)   (ae u_) (X)) (1 (w) (@)    (r)))
            ((2 (X)   (o_ oo)   (X)) (1 (r) (@)    (n j)))))




(setf cw2 '(((2 (K) (A_) (X)) (1 (R) (@) (T)))
            ((2 (B) (OO) (X)) (1 (L) (@) (T)))
            ((2 (L) (AE) (X)) (1 (D) (@) (R)))
            ((2 (D) (E)  (X)) (1 (V) (@) (L)))
            ((2 (P) (I)  (K)) (1 (N) (I) (K)))
            ((2 (T) (I)  (X)) (1 (K) (I) (T)))
            ((2 (Z) (I)  (X)) (1 (P) (@) (R)))
            ((2 (K) (AE) (X)) (1 (B) (@) (N)))))



(setf cw3 '(((2 (k r)  (o_) (X)))
            ((2 (s t)  (u_) (X)))
            ((2 (g l)  (u_) (X)))
            ((2 (t r)  (ee) (X)))
            ((2 (t r)  (a_) (X)))
            ((2 (d r)  (ah) (X)))
            ((2 (s n)  (o_) (X)))) )


(setf cw4 '(((2 (h) (ae) (t)))
            ((2 (b) (oo) (k)))
            ((2 (p) (e)  (n)))
            ((2 (r) (ae) (t)))
            ((2 (r) (uu) (g)))
            ((2 (p) (i)  (g)))
            ((2 (h) (e)  (n)))))

;;These are sets of similar words which are similar in different ways.
(setf sim1 '(((D R) (UU) (G))
             ((P L) (UU) (G))
             ((S P) (AE) (N))
             ((B R) (AE) (N))
             ((K R) (AW) (P))
             ((F L) (AW) (P))
             ((G R) (A_) (Z))
             ((B L) (A_) (Z))))

(setf sim2 '(((P R) (AW) (D))
             ((P L) (AW) (D))
             ((K R) (I)  (K))
             ((K L) (I)  (K))
             ((B R) (EE) (D))
             ((B L) (EE) (D))
             ((S T) (UU) (F))
             ((S N) (UU) (F))))

(setf sim3 '(((F R) (AW) (G))
             ((G R) (AW) (G))
             ((B L) (UU) (SH))
             ((P L) (UU) (SH))
             ((K L) (AE) (M))
             ((S L) (AE) (M))
             ((T R) (I) (P))
             ((D R) (I) (P))))

(setf sim4 '(((P R) (EE) (N))
             ((P R) (U)  (N))
             ((S L) (A_) (T))
             ((S L) (AE) (T))
             ((G L) (I)  (B))
             ((G L) (AW) (B))
             ((T R) (E)  (K))
             ((T R) (UU) (K))))



;;  These are some of the famous 'similar' word sets used by Baddeley and others in numerous experiments.
;;
(setf bad1 '(((2 (K) (AE) (N)))
             ((2 (K) (AE) (D)))
             ((2 (K) (AE) (T)))
             ((2 (K) (AE) (P)))
             ((2 (M) (AE) (N)))
             ((2 (M) (AE) (D)))
             ((2 (M) (AE) (T)))
             ((2 (M) (AE) (P)))))

(setf bad2 '(((2 (K) (AW U) (X)))
             ((2 (D) (A_)   (X)))
             ((2 (B) (AW)   (R)))
             ((2 (F) (ee U)  (X)))
             ((2 (H) (AE)   (T)))
             ((2 (P) (E)    (N)))
             ((2 (S) (UU)   (P)))
             ((2 (P) (I)    (T)))))

(setf bad1a (append bad1 '(((2 (m) (ae) (k s)))
                           ((2 (k) (ae) (b))))))

(setf bad2a (append bad2 '(((2 (r) (i) (g)))
                           ((2 (b) (uu) (n))))))

(setf 2a '(((2 (B) (AW) (T)))
           ((2 (S) (aw) (T)))
           ((2 (T) (AW) (T)) )
           ((2 (K) (AW) (T)) )
           ((2 (W) (AW) (T)))))

(setf 2b '(((2 (R)    (@)    (F)))
           ((2 (K)    (AW)   (F)))
           ((2 (Th R) (U_)   (X)))
           ((2 (D)    (O_)   (X)))
           ((2 (B)    (AE OO) (X)))))


(setf 2c '(((2 (P L) (EE) (X)) )
           ((2 (F R) (E) (N D)))
           ((2 (S L) (A_) (X)) )
           ((2 (R)   (O_) (X)) )
           ((2 (B)   (O_) (R D)))))

(setf 3a '(((2 (H) (Ae) (D)))
           ((2 (T) (Ae) (G)))
           ((2 (F) (Ae) (D)))
           ((2 (K) (Ae) (P)))
           ((2 (P) (Ae) (D)))
           ((2 (P) (Ae) (N)))
           ((2 (T) (Ae) (P)))
           ((2 (L) (Ae) (P)))
           ((2 (F) (Ae) (N)))
           ((2 (K) (Ae) (N)))))


(setf 3b '(((2 (T) (I)  (N)))
           ((2 (D) (E)  (N)))
           ((2 (K) (AW) (D)))
           ((2 (L) (I)  (D)))
           ((2 (K) (AE) (B)))
           ((2 (T) (UU) (G)))
           ((2 (F) (AW) (G)))
           ((2 (D) (I)  (G)))
           ((2 (F) (AE) (N)))
           ((2 (L) (E)  (D)))))

(setf 4a '(((2 (P) (O_) (R))  (1 (T) (UU) (X)))
           ((2 (K) (O_) (R))  (1 (V) (EE) (X)))
           ((2 (M) (O_) (R))  (1 (S) (UU) (X)))
           ((2 (B) (O_) (R))  (1 (G) (O_) (X)))
           ((2 (F) (O_) (R))  (1 (N) (EE) (X)))
           ((2 (L) (O_) (R))  (1 (D) (O_) (X)))))

(setf 4b '(((2 (X) (AE) (X))   (1 (S T R) (EE) (X)))
           ((2 (P) (O_) (X))   (1 (Z)  (O_) (X)))
           ((2 (D) (AW) (N))   (1 (Z)  (UU) (X)))
           ((2 (P) (A_) (X))   (1 (N)  (A_) (X)))
           ((2 (V) (E)  (X))   (1 (S P)  (A_) (X)))
           ((2 (J) (AW) (L))   (1 (L)  (O_) (X)))))

(setf 4c '(((1 (M) (Ee) (X))   (1 (N) (@) (R))  (2 (R) (Aw) (L))   (1 (L) (A_) (X)))
           ((1 (J) (E)  (X))   (1 (N) (@) (R))  (2 (R) (Aw) (X))   (1 (T) (O_) (X)))
           ((1 (X) (O_) (X))   (1 (N) (@) (R))  (2 (R) (Aw) (X))   (1 (T) (A_) (X)))
           ((1 (F) (U)  (X))   (1 (N) (@) (R))  (2 (R) (Aw) (L))   (1 (L) (Ee) (X)))
           ((1 (S) (Ee) (X))   (1 (N) (@) (R))  (2 (R) (Aw) (X))   (1 (M) (@)  (X)))
           ((1 (V) (E)  (X))   (1 (N) (@) (R))  (2 (R) (Aw) (R))   (1 (R) (A_) (X)))))

(setf 4d '(((1 (X)   (E)  (L))  (1 (L) (@)  (X))   (2 (F) (AW) (N))   (1( T) (A_) (X)))
           ((1 (N)   (AW) (X))  (1 (V) (EE) (X))   (2 (G) (AW) (R))   (1 (R) (A_) (X)))
           ((1 (P R) (E)  (X))  (1 (F) (@)  (R))   (2 (R) (E)  (N))   (1 (Z) (UU) (X)))
           ((1 (S)   (EE) (X))  (1 (G) (@)  (R))   (2 (R) (E)  (X))   (1 (T) (UU) (X)))
           ((1 (D)   (E)  (X))  (1 (M) (O_) (L))   (2 (L) (EE) (X))   (1 (T) (O_) (X)))
           ((1 (L)   (AW) (X))  (1 (P) (@)  (X))   (2 (D) (EE) (X))   (1 (N) (UU) (X)))))

;; Lists used in Experiment 2 of Mueller et al., 2003
;aka 2-long
(setf ph1 '(((2 (b) (a_)    (s)) (1 (m) (@) (n t)))
            ((2 (k) (ah)    (n)) (1 (sh) (@) (n s)))
            ((2 (d) (i)     (s)) (1 (ch) (ah) (r j)))
            ((2 (X) (e)     (n)) (1 (t r) (@) (n s)))
            ((2 (f) (ah)  (l s)) (1 (h) (oo) (d)))
            ((2 (h) (ah u_) (s)) (1 (h) (o_)  (l d)))
            ((2 (g r) (ee) (x))  (1 (v) (@)   (n s)))
            ((2 (m)   (i)  (X))  (1 (s t r) (@)  (s)))
            ((2 (sh)  (ee) (p))  (1 (s k) (i)  (n)))
            ((2 (t r) (ae) (k))  (1 (sh) (@)  (n)))))
;aka 3
(setf ph2 '(((2 (X) (ae) (k))    (1 (s) (@) (X))   (1 (d) (@) (n t)))
            ((1 (k l) (a_) (X))  (1 (r) (@) (X))   (2 (n) (e) (t)))
            ((2 (d)   (i) (X))   (1 (s) (@) (X))   (1 (p l) (i) (n)))
            ((1 (X)  (@)  (k))   (2 (s) (e) (p))   (1 (sh)  (@) (n)))
            ((2 (h)  (e)  (k))   (1 (s) (@) (X))   (1 (g)   (ah) (n)))
            ((2 (X)  (i)  (n))   (1 (d) (@) (X))   (1 (s t r) (ee) (X)))
            ((2 (p r)(o_) (X))  (1 (t) (@)   (X))  (1 (k)  (ah)  (l)))
            ((2 (r)  (i)  (X))  (1 (d) (@)   (X))  (1 (k)  (ee u_)   (l)))
            ((2 (s p) (e) (X))  (1 (s) (@) (X))    (1 (m) (@) (n)))
            ((1 (t r) (@) (X))  (2 (d) (i) (X))    (1 (sh) (@) (n)))))

;aka 2-short
(setf ph3 '(((1 (k) (@) (n))       (2 (t r) (o_) (l)))
            ((1 (d) (i) (X))       (2 (s p) (ee u_) (t)))
            ((1 (h) (i) (m))       (2 (s) (e)   (l f)))
            ((2 (X) (i) (m))       (1 (p r) (i) (n t)))
            ((2 (j) (uu) (ng k))   (1 (sh) (@) (n)))
            ((2 (m) (i) (k s))     (1 (ch) (@) (r)))
            ((2 (p r) (ee) (X))    (1 (f) (i) (k s)))
            ((1 (r)   (uu) (X))    (2 (s p) (e) (k t)))
            ((2 (s t) (ah ee) (X)) (1 (p) (@) (n d)))
            ((2 (t r) (uu) (m))    (1 (p) (@) (t)))))

;;Cowan's short versus long words.
(setf cows '(
             ((2 (d) (o_) (m)))
             ((2 (g) (a_) (t)))
             ((2 (l) (ae) (m p)))
             ((2 (n) (e) (s t)))
             ((2 (r) (ah ee) (s)))
             ((2 (t) (ae) (n k)))))
(setf cowl '(
             ((2 (b) (e) (d))           (1 (r) (u_) (m)))
             ((2 (k) (ah) (k))          (1 (t) (a_) (l)))
             ((2 (f) (oo) (t))          (1 (b) (aw) (l)))
             ((2 (h) (ah) (r d))        (1 (w) (a_) (r)))
             ((2 (p l) (ae) (t))        (1 (f) (o_) (r m)))
             ((2 (s) (uu) (n))          (1 (l) (ah ee) (t)))))



(setf l3b '(((1 (X)  (@) (d))    (2 (v) (ae)   (n))  (1 (t)  (i)   (j)))
           ((1 (b)  (ee) (X))  (2 (h) (a_)   (v))  (1 (v)  (ee @)   (r)))
          ((2 (s)  (@)  (r))  (1 (k) (@)    (m))  (1 (s t) (ae) (n s)))
           ((1 (d)  (ee) (X))  (2 (f) (aw ee)(X))  (1 (X)  (@)    (n s)))
           ((2 (f)  (ae) (n))  (1 (t) (@)    (s))  (1 (s)  (ee)   (X)))
           ((2 (m)  (i)  (X))  (1 (z) (@)    (r))  (1 (r)  (ee)   (X)))
           ((2 (n)  (ah) (r))  (1 (r) (o_)   (n))  (1 (n)  (e)    (s)))
           ((2 (P R)(O_) (X))  (1 (T) (@)    (X))  (1 (K)  (Aw)   (L)))
           ((2 (R)  (I)  (X))  (1 (D) (@)    (X))  (1 (K)  (ee U_)   (L)))
           ))


(setf ph1b '(((2 (b) (a_)    (s)) (1 (m) (@) (n t)))
            ((2 (k) (aw)    (n)) (1 (sh) (@) (n s)))
            ((2 (d) (i)     (s)) (1 (ch) (aw) (r j)))
            ((2 (X) (e)     (n)) (1 (t r) (@) (n s)))
            ((2 (f) (aw)  (l s)) (1 (h)   (oo) (d)))
            ((2 (g r) (ee) (x))  (1 (v) (@)   (n s)))
            ((2 (m)   (i)  (X))  (1 (s t r) (@)  (s)))
            ((2 (sh)  (ee) (p))  (1 (s k) (i)  (n)))
            ((2 (t r) (ae) (k))  (1 (sh) (@)  (n)))))

;; More of Baddeley's word sets.
(setf bad12 '((k ae n) (k ae d) (k ae t) (k ae p) (m ae n) (m ae d) (m ae t) (m ae p) (k aw u) (d a_)
(b aw r) (f ee u) (n aw t) (p e n) (s uu p) (p i t)))
(setf bad3 '((b ee) (s ee) (d ee) (j ee) (p ee) (t ee) (v ee)))
(setf bad4 '((a_ ch) (j ae) (e l) (aw r) (e s) (w aw ee) (z ee)))


(setf alphabet '((ee) (i) (a_) (e) (ae) (u) (@) (uu) (ah) (u) (oo) (o_) (aw) (y) (w) (r) (l) (h) (p) (b)
(t) (d) (ch) (j) (k) (g) (f) (v) (th) (thz) (s) (z) (sh) (zh) (m) (n) (ng)))


;;Lovatt, Avons, and Masterson, v. 1.
(setf lam1-short '(((2 (b)   (uu)    (X))  (1 (t) (@) (n)))
                   ((2 (t r) (ae)    (k))  (1 (t) (@) (r)))
                   ((2 (w)   (i)     (X))  (1 (s) (@) (l)))
                   ((2 (s p) (ah ee) (X))  (1 (d) (@) (r)))
                   ((2 (p)   (e)     (n))  (1 (s) (@) (l)))
                   ((2 (p)   (ah)    (X))  (1 (k) (@) (t)))
                   ((2 (sh)  (uu)    (X))  (1 (v) (@) (l)))
                   ((2 (k)   (ae)    (n))  (1 (d) (@) (l)))
                   ))


(setf lam1-long '(((2 (p) (e) (X))    (1 (b) (@) (l z)))
                  ((2 (k) (@) (r))    (1 (t) (@) (n z)))
                  ((2 (s t) (a_) (X)) (1 (sh) (@) (n)))
                  ((2 (n) (ee) (X))   (1 (d)  (@) (l)))
                  ((2 (b r) (ae) (n)) (1 (ch) (@) (z)))
                  ((1 (k) (@) (X) )   (2 (n)  (u_) (z)))
                  ((2 (n) (e) (k)  )  (1 (l)  (@) (s)))
                  ((2 (r) (o_) (X) )  (1 (b)  (ah) (t)))
                  ))

(setf lam2-short '(((2 (X) (aw) (X))  (1 (b l) (aw) (ng)))
                   ((2 (l) (e)  (X))  (1 (m)   (@)  (n)))
                   ((2 (p) (uu)  (X))  (1 (p)   (@)  (t)))
                   ((2 (w) (i)  (X))  (1 (z)   (@)  (r d)))
                   ((2 (k) (ae) (X))  (1 (m)   (@)  (l)))
                   ((2 (t) (ae) (X))  (1 (b l)   (@) (t)))
                   ((2 (k) (aw) (X))  (1 (f)   (@)  (n)))
                   ((2 (h) (ae) (X))  (1 (m)   (@)  (k)))
                   ))

(setf lam2-long '(((1 (g)   (uu) (X))  (2 (z) (e) (l)))
                  ((1 (b r) (o_) (X))  (2 (sh) (@) (r)))
                  ((2 (s)   (ah) (X))  (1 (r) (ee) (X)))
                  ((1 (k)   (ah) (r))  (2 (t) (u_) (n)))
                  ((2 (m)   (uu) (s))  (1 (t) (ae) (ng)))
                  ((2 (k)   (aw)  (X)) (1 (t) (@) (j)))
                  ((2 (p r) (o_) (X))  (1 (t) (ee) (n)))
                  ((2 (s)   (i)  (s))  (1 (t) (@) (r n)))
                  ))


(setf lam3-short '(((2 (b) (i)    (X)) (1 (sh) (@) (p)))
                   ((2 (p) (e)    (k)) (1 (t) (@) (n)))
                   ((2 (X) (e)    (m)) (1 (b) (@) (r)))
                   ((2 (W) (I)    (X)) (1 (K) (I) (T)))
                   ((2 (w) (i)    (X)) (1 (g) (@) (l)))
                   ((2 (p y) (ee u_) (X)) (1 (t) (@) (r)))
                   ((2 (t) (i)    (X)) (1 (p) (@) (l)))
                   ((2 (h) (ae)   (X)) (1 (k) (@) (l)))
                   ((1 (d) (@)    (X)) (2 (k) (o_) (r)))
                   ((2 (f) (ae)   (X))  (1 (l) (i)  (k)))
                   ))

(setf lam3-long '(((2 (f r) (ah ee) (X) ) (1 (d)   (a_) (X)))
                  ((1 (k)   (o_)    (X))  (2 (w)   (@)  (r s)))
                  ((1 (h y) (ee u_) (X))  (2 (m)   (a_) (n)))
                  ((1 (h)   (ah)    (r))  (2 (p)   (u_) (n)))
                  ((2 (n)   (ah ee) (X))  (1 (t r) (a_) (t)))
                  ((2 (s)   (ah ee) (X))  (1 (k l) (o_) (n)))
                  ((2 (m)   (o_)    (r))  (1 (f)   (ee) (n)))
                  ((1 (t)   (ah ee) (X))  (2 (k)   (u_) (n)))
                  ((2 (v)   (u_)   (X))   (1 (d)   (u_)  (X)))
                  ((2 (z)  (ah ee) (X))   (1 (g)   (o_)   (t)))
                  ))


;;;These stimuli were used in Lovatt, Avon's and Masterson, 2002
(setf lam2-shortb '(
		   ((2 (l) (e)  (X))  (1 (m)   (@)  (n)))
                   ((2 (w) (i)  (X))  (1 (z)   (@)  (r d)))
                   ((2 (k) (ae) (X))  (1 (m)   (@)  (l)))
                   ((2 (t) (ae) (X))  (1 (b l)   (@) (t)))
                   ((2 (h) (ae) (X))  (1 (m)   (@)  (k)))
                   ))

(setf lam2-longb '(((1 (g)   (uu) (X))  (2 (z) (e) (l)))
                  ((1 (b r) (o_) (X))  (2 (sh) (@) (r)))
                  ((2 (k)   (aw)  (X)) (1 (t) (@) (j)))
                  ((2 (p r) (o_) (X))  (1 (t) (ee) (n)))
                  ((2 (s)   (i)  (s))  (1 (t) (@) (r n)))
                  ))

;;laureen ohanlon's stimuli

(setf lo1 '(((2 (sh) (e) (r))    (1 (r) (ee) (X)) )
            ((2 (sh) (e) (l))    (1 (b) (ee) (X)) )
            ((2 (sh) (e) (l))    (1 (l) (ee) (X)) )
            ((2 (sh) (@) (r))    (1 (l) (ee) (X)) )
            ))


(setf lo2 '(((1 (m) (@) (r))    (2 (r) (i) (X))     (1 (s) (@) (x)) )
            ((1 (m) (@) (r))    (2 (r) (i) (X))     (1 (t) (@) (x)) )
            ((1 (m) (@) (l))    (2 (l) (i) (n))     (1 (d) (@) (x)) )
            ((1 (m) (@) (r))    (2 (r) (ee) (X))    (1 (n) (@) (x)) )
            ))


(setf lo3 '(((2 (r) (ah) (d))    (1 (n) (ee) (X)) )
            ((2 (r) (ah) (X))    (1 (k) (ee) (X)) )
            ((2 (r) (ah) (X))    (1 (b) (ee) (X)) )
            ((2 (r) (ah) (X))    (1 (n) (ee) (X)) )
  ))

  
(setf lo4 '(((2 (G r) (e) (X))    (1 (g)   (@) (r))     (1 (r) (ee) (X)) )
            ((2 (G)  (a_) (X))    (1 (b r) (ee) (X))    (1 (X) (@)  (l)) )
            ((2 (G)  (a_) (r))    (1 (r)   (@) (X))     (1 (s) (uu) (n)) )
            ((2 (G)  (ae) (l))    (1 (l)   (@) (X))     (1 (h) (ae) (d)) )
              ))
  
  
  
(setf lo5 '(((2 (P)   (ah ee) (l))     (1 (l) (@) (t)) )
            ((2 (P)   (ah ee) (r))     (1 (r) (@) (t)) )
            ((2 (P r) (ah ee) (X))     (1 (v) (@) (t)) )
            ((2 (P r) (ee)    (l))     (1 (l) (@) (t)) )
            ))


(setf lo6 '(((2 (X) (ae) (X))   (1 (n)   (@) (l))    (1 (l) (@)  (s t)) )
            ((2 (X) (ae) (k))   (1 (t)   (@) (X))    (1 (v) (@)  (s t)) )
            ((2 (X) (ae) (d))   (1 (v)   (@) (X))    (1 (k) (@)  (t))   )
            ((2 (X) (ae) (X))   (1 (k r) (@) (X))    (1 (b) (ae) (t))   )
             ))


(setf lo7 '(((2 (t r) (a_) (X))     (1 (n)   (@) (r)) )
            ((2 (t)   (a_) (l))     (1 (l)   (@) (r)) )
            ((2 (t r) (a_) (X))     (1 (d)   (@) (r)) )
            ((2 (t)   (a_) (X))     (1 (s t) (@) (r)) )
            ))

(setf lo8 '(((1 (k l) (i) (X))     (2 (n)   (i)  (X))    (1 (sh) (@) (n)))
           ((1 (k)   (@) (X))     (2 (m)   (ae) (n))    (1 (d)  (@) (r)))
           ((1 (k)   (@) (n))     (2 (t r) (o_) (l))    (1 (l)  (@) (r)))
           ((1 (k)   (@) (m))     (2 (p)   (o_) (X))    (1 (s)  (@) (r)))
            ))


(setf lo1d '(((2 (s t) (e) (X)) (1 (f) (@) (X))   (1 (n) (ee) (X)))
              ((2 (n) (o_) (r)) (1 (m) (@) (X)))
              ((2 (X) (i) (X))  (1 (z) (@) (X))   (1 (b) (e) (l)))
              ((2 (j) (e)(X))   (1 (s) (@) (X))   (1 (k) (@) (X)))))

(setf lo2d '(((2 (k) (ae) (n))  (1 (d) (@) (s)))
             ((2 (k) (i) (m))  (1 (b) (@) (r))  (1 (l) (ee) (X)))
             ((2 (l) (ee) (X)) (1 (s) (@) (X)))
             ((1 (d) (e) (X))  (1 (s) (@) (X))  (2 (r) (a_) (X)))))

(setf lo3d '(((2 (m) (i) (X))   (1 (ch)  (@) (l)))
             ((2 (n) (o_) (l)))
             ((2 (s k) (ah) (t)))
             ((2 (p) (ah) (l)))
             ))


(setf lo4d '(((2 (b r) (ae) (n))   (1 (d) (@) (n)))
             ((2 (t r) (e) (X))   (1 (v) (@) (r)))
             ((2 (n) (i) (X))     (1 (k) (@) (X))    (1 (l) (@) (s)))
             ((2 (r) (ae) (m))    (1 (s) (ee) (X)))
             ))

(setf lo5d '(((1 (X) (ee) (X))     (1 (l) (e) (k))    (2 (t r) (i) (X))    (1 (sh) (@) (n)))
             ((1 (l) (ah ee) (X))  (2 (b r) (a_) (X)) (1 (r) (ee)(X))      (1 (X) (@) (n)))
             ((1 (z) (u_) (X))     (2 (X) (ah) (X))   (1 (l) (@) (X))      (1 (g) (i) (s t)))
             ((2 (h) (ah) (w))     (1 (k) (@) (r)))
             ))


(setf lo6d '(((1 (b) (oo) (X))  (2 (ch) (@) (r)))
             ((1 (X) (e) (n))   (2 (s) (@) (n)))
             ((1 (m) (@) (X))   (2 (j) (i) (X))   (1 (sh) (@) (n)))
             ((2 (s) (a_) (l s)) (1 (p) (@) (r))   (1 (s) (@) (n)))
             ))

(setf lo7d '(((2 (m) (@) (r))       (1 (ch) (@) (n t)))
             ((2 (k) (oo) (k)))
             ((1 (X) (aw) (k))       (1 (sh) (@) (X))    (2 (n) (ee) (r)))
             ((2 (f l) (ah oo) (X))  (1 (t) (@) (s t)))
             ))

(setf lo8d '(((2 (X) (uu) (n))     (1 (d) (@) (r))   (2 (t) (a_) (X))  (1 (k) (@) (r)))
             ((2 (d) (i) (p))      (1 (l) (o_)(X))   (1 (m) (ae) (t)))
             ((2 (m) (ah) (X))     (1 (d) (@) (l)))
             ((2 (j) (uu) (r))     (1 (n) (@) (X))   (1 (l) (@) (s t)))
             ))





;;Baddeley, Thomson, and Buchanan, 1975, exp. 5
(setf btb1 '(((2 (s t)   (o_) (t)))
             ((2 (m)     (uu) (m p s)))
             ((2 (s k)   (u_) (l)))
             ((2 (g r)   (ee) (s)))
             ((2 (k r)   (u_) (X)))
             ((2 (s w)   (i)  (t ch)))
             ((2 (m)     (ae) (th z)))
             ((2 (m)     (a_) (n)))
             ((2 (s k r) (o_) (l)))
             ((2 (z)     (i)  (n k)))
             ))

(setf btb2 '(((2 (p) (u_) (X))       (1 (m) (uu) (X)))
             ((2 (m) (ee) (X))     (1 (z) (@) (l s)))
             ((2 (k) (ah) (x))       (1 (l) (@) (g)))
             ((1 (p) (@) (X) )      (2 (r) (u_) (X)))
             ((2 (b l) (ae) (k))    (1 (p) (u_) (l)))
             ((2 (k) (e) (X))       (1 (t) (@) (l)))
             ((2 (f) (i) (x))       (1 (s) (i) (k s)))
             ((2 (Y) (u_) (X))      (1 (t) (ah) (X)))
             ((2 (X) (e)  (X))      (1 (s) (a_) (X)))
             ((2 (k) (ah) (r))      (1 (b) (@) (n)))
              ))

(setf btb3 '(((1 (g) (@) (X))       (2 (r) (i) (l))     (1 (X) (uu) (X)))
             ((2 (l) (e) (p))       (1 (r) (@)(X))      (1 (s) (ee) (X)))
             ((2 (n) (@) (r))       (1 (s) (@) (X))     (1 (r) (ee) (X)))
             ((2 (m) (e) (k))       (1 (s) (@) (X))     (1 (k) (o_) (X)))
             ((2 (X) (e) (k))       (1 (s) (@) (X))     (1 (t) (@)  (r)))
             ((2 (r) (a_) (X))      (1 (d) (ee) (X))    (1 (X) (o_) (X)))
             ((2 (b) (ah) (X))      (1 (t) (@) (X))     (1 (n) (ee) (X)))
             ((1 (w) (ah ee) (X))   (2 (X) (o_) (X))    (1 (m) (i) (ng)))
             ((2 (b) (uu) (X))      (1 (l) (@) (X))     (1 (t) (@)  (n)))
             ((2 (k) (ae) (l))      (1 (s) (ee) (X))    (1 (X) (uu) (m)))
             ))

(setf btb4 '(((1 (r) (ah ee) (X))   (2 (n) (ah) (X))     (1 (s) (@) (X))     (1 (r) (@) (s)))
        ((1 (d) (i)     (p))   (2 (th) (ee) (X))    (1 (r) (ee) (X))    (1 (X) (@)   (X)))
        ((1 (X) (@) (X))       (2 (k)  (ae) (X))    (1 (d)  (@) (X))    (1 (m) (ee) (X)))
        ((1 (X) (aw) (X))      (2 (s t r) (a_) (X)) (1 (l) (ee) (X))    (1 (X) (@) (X)))
        ((1 (w) (uu) (l))      (1 (v) (@) (r))      (2 (h) (ae) (m p))  (1 (t) (@) (n)))
        ((2 (t) (e) (X))       (1 (l) (@) (X))      (1 (v) (i) (X))     (1 (zh) (@) (n)))
        ((1 (b) (ah ee) (X))   (2 (X) (aw) (X))     (1 (l) (@) (X))     (1 (g) (ee) (X)))
        ((1 (X) (ae) (X))     (1 (l) (@) (X))      (2 (b) (ae) (X))    (1 (m)  (@) (X)))
        ((2 (d) (i) (k))       (1 (sh) (uu) (X))    (1 (n) (a_) (X))    (1 (r) (ee) (X)))
        ((1 (y) (u_) (X))      (2 (r) (a_) (X))     (1 (n) (ee) (X))    (1 (X) (uu) (m)))
        ))
      
      
      
(setf btb5 '(((1 (h) (i) (X))  (1 (p) (o_) (X))    (2 (p) (ah) (X))    (1 (t) (@) (X))  (1 (m) (@) (s)))
        ((1 (t) (u_) (X)) (2 (b) (@) (r))     (1 (k) (ee u_) (X)) (2 (l) (o_)(X))  (1 (s) (@) (s)))
        ((1 (y) (u_) (X)) (1 (n) (@) (X))     (2 (v) (@) (r))     (1 (s) (i) (X))  (1 (t) (ee) (X)))
        ((1 (y) (u_) (X)) (1 (g) (o_) (X))    (2 (s l) (ah) (X))  (1 (v) (ee) (X)) (1 (X) (@) (X)))
        ((2 (w) (e) (s))  (1 (t) (@) (n))     (1 (s) (u_) (X))    (1 (p) (@) (r))  (2 (m) (a_) (r)))
        ((1 (r) (e) (X))  (2 (f r) (i) (X))   (1 (g) (@) (X))     (1 (r) (a_) (X)) (1 (t) (@) (r)))
        ((1 (f) (i) (X))  (1 (z)  (ee) (X))   (2 (X) (ah) (X))    (1 (l) (@) (X))  (1 (g) (ee) (X)))
        ((1 (l) (u_) (X)) (1 (X) (ee) (X))    (1 (Z) (ee) (X))    (2 (X) (ae) (X)) (1 (n) (@) (X)))
        ((1 (p) (ee) (X)) (1 (r) (ee) (X))    (2 (X) (ah) (X))    (1 (d) (@) (X))  (1 (k) (@) (l)))
        ((1 (X) (ae) (X)) (1 (l) (ee u_) (X)) (2 (m) (i) (X))     (1 (n) (ee) (X)) (1 (X) (@) (m)))
             ))






;; These are some nonwords we made up.
;;

(setf nonwords1 '(
                  ((2(x)(ae)(m))     (1(p)(o_)(r d)))   ;ampord
                  ((2(b)(e)(x))      (1(f l)(i)(n)))    ;beflin
                  ((2(K)(@)(r))      (1(p)(@)(r)))      ;curper
                  ((2(d r)(i)(k))    (1(t)(e)(l)))      ;drictell
                  ((2(h)(ah)(r))     (1(k)(@)(nt)))     ;harkent
                  ((2(m)(u)(k t))    (1(l)(ee)(x)))     ;muctly
                  ((2(r)(uu)(k))     (1(t)(ae)(nt)))    ;ructant
                  ((2(s t)(ae)(k))   (1(n)(@)(r)))      ;stakner
                  ((2(t)(o_)(r))     (1(S)(@)(N)))      ;torsen
                  ((2(w)(@)(r))      (1(f)(@)(r)))      ;werfer                                                         
                 ))



(setf nonwords2 '(
                  ((2(x)(e)(n t))    (1(l)(ee)(x)))    ;ently
                  ((2(b)(ae)(X))     (1(b l)(e)(sh)))  ;bablesh
                  ((2(k)(ae)(n))     (1(d)(@)(n)))     ;candin
                  ((2(d)(ah)(x))      (1(n)(i)(ch)))    ;donnich
                  ((2(h)(ah)(r))     (1(s)(o_)(x)))    ;harso
                  ((2(m)(@)(x))      (1(n)(ee)(r)))    ;moneer
                  ((2(P)(ae)(k))     (1(t r)(uu )(x))) ;pactra
                  ((2(r)(o_)(x))     (1(k)(ae)(n)))    ;rocan
                  ((2(s)(ah)(r))      (1(k)(@)(d)))    ;sarked
                  ((2(t)(o_)(r))     (1(m)(i)(m)))     ;tormim
                  ))




(setf nonwords3 '(
                  ((2(x)(ah)(n))     (1(t r)(@)(m)))    ;ontrom
                  ((2(b)(a_ee)(x))   (1(y)(@)(s)))      ;bayess
                  ((2(k l)(ah)(n))   (1(t)(@)(n)))      ;clantin
                  ((2(d)(ee)(x))     (1(t)(@)(n)))      ;detin
                  ((2(h)(i)(X))      (1(l)(i)(p)))      ;hillip
                  ((2(m)(@)(r))      (1(l)(ee)(x)))     ;murly       
                  ((2(p)(ah)(s))      (1(k)(@)(r)))     ;posker
                  ((2(s)(e)(k))      (1(t)(i)(f)))      ;sectif
                  ((2(th)(ah ee)(x)) (1(d)(@)(n)))      ;thydin
                  ((2(w)(i)(X))      (1(n)(ah)(l t)))   ;whinalt
                  ))


(setf nonwords-other '(
                        ((2(x)(e)(k))      (1(s ch)(@)(r))) ;exture
                        ((2(d)(ah u_)(w))  (1(l)(ee)(x)))   ;dowly
                        ((2(h)(i)(k))      (1(t)(o_)(x)))   ;hicto
                        ((2(s m)(i)(n))    (1(t)(o_)(x)))   ;sminto
                        ((2(s)(@)(n t))    (1(l)(ee)(x)))   ;sently
                        ((2(x)(i)(x))      (1(t)(e)(n)))    ;itten
                        ((2(m)(o_)(n))     (1(w)(i)(t)))    ;munwit                           
                        ((2(l)(o_)(x))     (1(t)(i)(k)))    ;lotick
                        ((2(k)(ae)(n t))   (1(l)(ee)(x)))   ;cantly
                       ((2(p)(u)(l))      (1(d)(i)(f)))     ;puldif
                       ))

;; Letter set used by Henson et al.

(DEFVAR *HENSON-STIM '(
                       ((2 (B) (EE) (X)))   ;"B"
                       ((2 (D) (EE) (X)))   ;"D"
                       ((2 (G) (EE) (X)))   ;"G"
                       ((2 (P) (EE) (X)))   ;"P"
                       ((2 (T) (EE) (X)))   ;"T"
                       ((2 (V) (EE) (X)))   ;"V"
                       ((2 (X) (A_) (CH)))  ;"H"
                       ((2 (K) (A_ ) (Y)))  ;"K"
                       ((2 (X) (E) (M)))    ;"M"
                       ((2 (K Y) (OO_) (X)))  ;"Q"
                       ((2 (X) (AH) (R)))     ;"R"
                       ((2 (W) (A_ EE) (X)))  ;"Y"
                       ))


;;From Baddeley 1966.
(defvar badd-66-1 '(
                    ((2 (M)(AE)(D)))
                    ((2 (M)(AE)(N)))
                    ((2 (M)(AE)(T)))
                    ((2 (M)(AE)(P)))
                    ((2 (K)(AE)(D)))
                    ((2 (K)(AE)(N)))
                    ((2 (K)(AE)(T)))
                    ((2 (K)(AE)(P)))
                    
                    ))
(DEFVAR BADD-66-2 '(  
                    ((2 (K)(AH UU)(X)))
                    ((2 (D)(A_)(Y)))
                    ((2 (B)(AH)(R)))
                    ((2 (F)(EE UU)(X)))
                    ((2 (H)(AH)(T)))
                    ((2 (P)(E)(N)))
                    ((2 (S)(UU)(P)))
                    ((2 (P)(I)(T)))
                    ))

(DEFVAR BADD-66-3 '(
                    ((2 (B)(I)(G)))
                    ((2 (L)(AH)(NG)))
                    ((2 (B R)(AH)(D)))
                    ((2 (G R)(A_)(T)))
                    ((2 (H)(AH EE)(X)))
                    ((2 (T)(AH )(L)))
                    ((2 (L)(AH)(R J)))
                    ((2 (W)(AH EE)(D)))
                    ))

(defvar BADD-66-4 '(
                    ((2 (X)(O_)(L D)))
                    ((2 (D)(EE)(P)))
                    ((2 (F)(AH U_)(L)))
                    ((2 (L)(A_)(T)))
                    ((2 (S)(A_)(F)))
                    ((2 (H)(AH)(T)))
                    ((2 (S T R)(AH)(NG)))
                    ((2 (TH)(I)(N)))
                    ))
